+ );
+ },
+);
+
+Tabs.displayName = "Tabs";
diff --git a/packages/ui/tsup.config.ts b/packages/ui/tsup.config.ts
index c44c86e..7888df4 100644
--- a/packages/ui/tsup.config.ts
+++ b/packages/ui/tsup.config.ts
@@ -4,11 +4,12 @@ import { defineConfig } from "tsup";
/**
* Auto-discover all component entry points
* Looks for src/ComponentName/ComponentName.ts files where the folder name matches the file name
*/
-const allFiles = glob.sync("src/**/[A-Z]*.ts", {
+const allFiles = glob.sync("src/**/[A-Z]*.{ts,tsx}", {
ignore: [
"**/*.test.ts",
+ "**/*.test.tsx",
"**/*.stories.ts",
"**/types.ts",
"**/tokens.ts",
@@ -21,11 +22,11 @@ const allFiles = glob.sync("src/**/[A-Z]*.ts", {
});
// Filter to only include files where the folder name matches the file name
// e.g., src/Button/Button.ts is included, but src/Button/helpers.ts is not
const entries = allFiles.filter((file) => {
const dir = path.dirname(file);
const folderName = path.basename(dir);
- const fileName = path.basename(file, ".ts");
+ const fileName = path.basename(file).replace(/\.(ts|tsx)$/, "");
return folderName === fileName;
});
@@ -4,11 +4,12 @@ import { defineConfig } from "tsup";
/**
* Auto-discover all component entry points
- * Looks for src/ComponentName/ComponentName.ts files where the folder name matches the file name
+ * Looks for src/ComponentName/ComponentName.tsx files where the folder name matches the file name
*/
@@ -21,11 +22,11 @@ const allFiles = glob.sync("src/**/[A-Z]*.ts", {
});
// Filter to only include files where the folder name matches the file name
-// e.g., src/Button/Button.ts is included, but src/Button/helpers.ts is not
+// e.g., src/Button/Button.tsx is included, but src/Button/helpers.ts is not
const entries = allFiles.filter((file) => {
const dir = path.dirname(file);